# electric

It is an electric calculation package
[Documment](https://nishizumi-lab.github.io/libs/flutter/01_package/electric/docs/html/index.html)


# 参考資料


## 電気主任技術者関連

[地上設置型太陽光発電システムの設計ガイドライン2019年版](https://www.nedo.go.jp/activities/ZZJP2_100060.html#guideline)

[経済産業省 法令｜電力の安全](https://www.meti.go.jp/policy/safety_security/industrial_safety/law/index.html)

[電気事業法　告示・内規等](https://www.meti.go.jp/policy/safety_security/industrial_safety/law/denjikokuji.html)

[JIS C 8955（太陽電池アレイ用支持物の設計用荷重算出方法）の改定内容](https://www.safety-chugoku.meti.go.jp/denki/hatsuden/taiyoukou/file/seminarshiryou2.pdf)

# Sample code

```
    final wp = WindPressure();



    // @param Zb 地表面粗度区分で定まる値(JIS C 8955 表4) 5
    // @param Zg 地表面粗度区分で定まる値(JIS C 8955 表4) 450
    // @param alpha 地表面粗度区分で定まる値(JIS C 8955 表4) 0.20
    // @param H アレイ面の平均地上高(m)(アレイの最大高さと最小高さの中間で架台構造により決まる) 1.789
    // @retval 平均風速の高さ方向の分布を表す係数Er
    print(wp.calcEr(5, 450, 0.20, 1.789)); // 0.6911947320312629

    // @brief 平均風速の高さ方向の分布を表す係数Er、ガスト影響係数Gfから環境係数Eを計算します。
    // @param Er 平均風速の高さ方向の分布を表す係数(calcErで計算) 0.691
    // @param Gf ガスト影響係数（※突風の影響を示す）(JIS C 8955 表3) 2.5
    // @retval 環境係数E
    print(wp.calcE(0.691, 2.5)); // 1.1937024999999999

    // @brief 設計用基準風速V0、環境係数E、用途係数Iwから設計用速度圧qを計算します。
    // @param V0 設計用基準風速V0(m/s)(JIS C 8955 表2より地域で決まる) 34
    // @param E 環境係数E(calcEで計算) 1.194
    // @param Iw 用途係数Iw(JIS C 8955 表5より利用用途で決まる) 1.0
    // @retval 設計用速度圧q 828.1583999999998
    print(wp.calcQp(34, 1.194, 1.0)); // 828.1583999999998

    // @fn calcCa
    // @brief 太陽電池アレイの傾斜角度もしくは相対角度と設置形態から風圧係数Caを計算します。
    // @param theta 太陽電池アレイの傾斜角度もしくは相対角度(架台構造と地盤傾斜により決まる)[deg]
    // @param type 設置形態。1:地上設置(正圧)、2:地上設置(負圧)、3:勾配屋根設置(正圧)、4:勾配屋根設置(負圧)、5:陸屋根設置(正圧、端部アレイ)、6:陸屋根設置(正圧、中央部アレイ)、7:陸屋根設置(負圧、端部アレイ)、8:陸屋根設置(負圧、中央部アレイ) ※ 正圧は順風、負圧は逆風ともいいます。
    // @retval アレイの風圧係数Ca
    print(wp.calcCa(20, 1)); // 1.25  傾斜角度(相対角)20degで地上設置(正圧)の場合
    print(wp.calcCa(20, 2)); // 1.61  傾斜角度(相対角)20degで地上設置(負圧)の場合
    print(wp.calcCa(0, 1)); // 0.35  傾斜角度(相対角)20degで地上設置(正圧)の場合
    print(wp.calcCa(0, 2)); // 0.85  傾斜角度(相対角)20degで地上設置(負圧)の場合

    // @brief 風力係数C、設計用速度圧q、受風面積Aから風圧荷重を計算します。
    // @param C アレイ面，支持物構成材の風力係数(アレイ面についてはcalcCa、支持物についてはJIS C 8955 表もしくは風洞実験等により計算) 1.25
    // @param q 設計用速度圧q(calcQpで計算) 828
    // @param A アレイ面の受風面積，支持物構成材の鉛直投影面積A（m2）(架台構造から計算、単位平方面積で考えるなら1) 1.0
    // @retval アレイ，支持物構成材に作用する風圧荷重W（N） 1035.0
    print(wp.calcW(828, 1.25, 1.0)); // 1035.0 傾斜角(相対角)20degで地上設置(正圧)の場合
    print(wp.calcW(828, -1.61, 1.0)); // -1333.08 傾斜角(相対角)20degで地上設置(負圧)の場合(※正圧方向を正として、風圧係数は負の値にしている)
    print(wp.calcW(828, 0.35, 1.0)); // 289.79 傾斜角(相対角)0degで地上設置(正圧)の場合
    print(wp.calcW(828, -0.85, 1.0)); // -703.8 傾斜角(相対角)0degで地上設置(負圧)の場合(※正圧方向を正として、風圧係数は負の値にしている)
```


